/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Swarco Traffic Systems GmbH
 * Adolf-Dambach-Strae
 * D-76571 Gaggenau
 * Phone: +49-7225-64-0
 * Fax: +49-7225-64-300
 * mailto: office.sts@swarco.de
 */

package de.bsvrz.ste.agzs.tls;

import java.util.List;
import java.util.Vector;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.ReferenceArray;
import de.bsvrz.dav.daf.main.config.Aspect;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Klasse fr die Auswertung der AttributGruppe atg.anzeigeQuerschnittQuellenVlt am
 * AnzeigeQuerschnitt und Bereitstellung der enthaltenen Daten.
 *
 * @version $Revision: 1.2 $ / $Date: 2012/11/29 11:49:42 $ / ($Author: Drapp $)
 *
 * @author Swarco Traffic Systems GmbH
 * @author Thomas Drapp
 *
 */
public class AnzeigeQuerschnittQuellenVlt
{
  /**
   * DebugLogger fr Debug-Ausgaben.
   */
  private static Debug m_debug = Debug.getLogger();
  /**
   * Datenverteilerverbindung.
   */
  private ClientDavInterface m_connection;
  /**
   * Datenmodell.
   */
  private DataModel m_dataModel;
  /**
   * Kennung, ob die Daten versorgt sind.
   */
  private boolean m_versorgt = false;
  /**
   * DE's die die Information Stromausfall liefern.
   */
  private List<SystemObject> m_desStromausfall = new Vector<SystemObject>();
  /**
   * AttributGruppe, die die Daten zum Stromausfall liefert.
   */
  private AttributeGroup m_atgStromausfall = null;
  /**
   * Aspekt, unter dem die Daten zum Stromausfall geliefert werden.
   */
  private Aspect m_aspStromausfall = null;
  /**
   * Attribut, das die Stromausfall-Information enthlt.
   */
  private String m_attributStromausfall = "";
  /**
   * Wert des Attribut, das den Stomausfall anzeigt.
   */
  private String m_attributWertStromausfall = "";
  /**
   * Kennung, ob die enthaltenen Daten zur Stromausfall-Erkennung einsetzbar bzw. versorgt sind.
   */
  private boolean m_versorgtStromausfall = false;
  /**
   * DE's die die Information Stromausfall liefern.
   */
  private List<SystemObject> m_desTuerkontakt = new Vector<SystemObject>();
  /**
   * AttributGruppe, die die Daten zum Trkontakt liefert.
   */
  private AttributeGroup m_atgTuerkontakt = null;
  /**
   * Aspekt, unter dem die Daten zum Trkontakt geliefert werden.
   */
  private Aspect m_aspTuerkontakt = null;
  /**
   * Attribut, das die Trkontakt-Information enthlt.
   */
  private String m_attributTuerkontakt = "";
  /**
   * Wert des Attribut, das den Trkontakt anzeigt.
   */
  private String m_attributWertTuerkontakt = "";
  /**
   * Kennung, ob die enthaltenen Daten zur Trkontakt-Erkennung einsetzbar bzw. versorgt sind.
   */
  private boolean m_versorgtTuerkontakt = false;
  
  /**
   * Konstruktur mit bergabe der notwendigen Informationen, um die AttributGruppe auswerden zu knnen.
   * 
   * @param connection Datenverteiler-Verbindung.
   * @param anzeigeQuerschnitt betroffener AnzeigeQuerschnitt.
   */
  public AnzeigeQuerschnittQuellenVlt(ClientDavInterface connection, ConfigurationObject anzeigeQuerschnitt)
  {
    m_connection = connection;
    m_dataModel = m_connection.getDataModel();
    
    AttributeGroup atg = m_dataModel.getAttributeGroup("atg.anzeigeQuerschnittQuellenVlt");
    
    if (atg != null)
    {
      Data data = anzeigeQuerschnitt.getConfigurationData(atg);
      
      if (data != null)
      {
        Data data2 = data.getItem("Stromausfall");
        
        ReferenceArray array = data2.getReferenceArray("DeVltReferenzen");

        int anzahlDes = array.getLength();

        if (anzahlDes > 0)
        {
          for (int i = 0; i < anzahlDes; i++)
          {
            SystemObject deVlt = array.getSystemObject(i);
            
            m_desStromausfall.add(deVlt);
            
            m_debug.fine("Stromausfall DE " + i + " ist " + deVlt);
          }
          
          SystemObject atgObjekt = data2.getReferenceValue("AttributGruppenReferenz").getSystemObject();
          
          if (atgObjekt != null)
          {
            m_atgStromausfall = (AttributeGroup)atgObjekt;
            
            m_debug.fine("Stromausfall ATG " + m_atgStromausfall);
          }

          SystemObject aspObjekt = data2.getReferenceValue("AspektReferenz").getSystemObject();
          
          if (aspObjekt != null)
          {
            m_aspStromausfall = (Aspect)aspObjekt;

            m_debug.fine("Stromausfall ASP " + m_aspStromausfall);
          }
          
          m_attributStromausfall = data2.getTextValue("Attribut").getValueText();

          m_debug.fine("Stromausfall Attribut '" + m_attributStromausfall + "'");

          m_attributWertStromausfall = data2.getTextValue("Attributwert").getValueText();

          m_debug.fine("Stromausfall Attributwert '" + m_attributWertStromausfall + "'");
          
          if ((m_desStromausfall.size() > 0) && (m_atgStromausfall != null) && (m_aspStromausfall != null) && (m_attributStromausfall.length() > 0) && (m_attributWertStromausfall.length() > 0))
          {
            m_versorgtStromausfall = true;
          }
        }
        
        data2 = data.getItem("Trkontakt");
        
        array = data2.getReferenceArray("DeVltReferenzen");

        anzahlDes = array.getLength();

        if (anzahlDes > 0)
        {
          for (int i = 0; i < anzahlDes; i++)
          {
            SystemObject deVlt = array.getSystemObject(i);
            
            m_desTuerkontakt.add(deVlt);
            
            m_debug.fine("Trkontakt DE " + i + " ist " + deVlt);
          }
          
          SystemObject atgObjekt = data2.getReferenceValue("AttributGruppenReferenz").getSystemObject();
          
          if (atgObjekt != null)
          {
            m_atgTuerkontakt = (AttributeGroup)atgObjekt;
            
            m_debug.fine("Trkontakt ATG " + m_atgTuerkontakt);
          }

          SystemObject aspObjekt = data2.getReferenceValue("AspektReferenz").getSystemObject();
          
          if (aspObjekt != null)
          {
            m_aspTuerkontakt = (Aspect)aspObjekt;

            m_debug.fine("Trkontakt ASP " + m_aspTuerkontakt);
          }
          
          m_attributTuerkontakt = data2.getTextValue("Attribut").getValueText();

          m_debug.fine("Trkontakt Attribut '" + m_attributTuerkontakt + "'");

          m_attributWertTuerkontakt = data2.getTextValue("Attributwert").getValueText();

          m_debug.fine("Trkontakt Attributwert '" + m_attributWertTuerkontakt + "'");
          
          if ((m_desTuerkontakt.size() > 0) && (m_atgTuerkontakt != null) && (m_aspTuerkontakt != null) && (m_attributTuerkontakt.length() > 0) && (m_attributWertTuerkontakt.length() > 0))
          {
            m_versorgtTuerkontakt = true;
          }
        }
        
        m_versorgt = true;
      }
      else
      {
        m_debug.error("AttributGruppe atg.anzeigeQuerschnittQuellenVlt am AnzeigeQuerschnitt " + anzeigeQuerschnitt + " nicht versorgt");
      }
    }
  }

  /**
   * Holt die Information, ob die AttributGruppe versorgt ist.
   * 
   * @return <code>true</code>, wenn versorgt, sonst <code>false</code>.
   */
  public boolean isVersorgt()
  {
    return m_versorgt;
  }

  /**
   * Holt die Liste der versorgten DE's fr die Erkennung des Stromausfalls.
   * 
   * @return Liste der versorgten DE's fr die Erkennung des Stromausfalls.
   */
  public List<SystemObject> getDesStromausfall()
  {
    return m_desStromausfall;
  }

  /**
   * Holt die AttributGruppe, die die Daten zum Stromausfall liefert.
   * 
   * @return AttributGruppe, die die Daten zum Stromausfall liefert.
   */
  public AttributeGroup getAtgStromausfall()
  {
    return m_atgStromausfall;
  }

  /**
   * Holt den Aspekt, unter dem die Daten zum Stromausfall geliefert werden.
   * 
   * @return Aspekt, unter dem die Daten zum Stromausfall geliefert werden.
   */
  public Aspect getAspStromausfall()
  {
    return m_aspStromausfall;
  }

  /**
   * Holt das Attribut, das die Stromausfall-Information enthlt.
   * 
   * @return Attribut, das die Stromausfall-Information enthlt.
   */
  public String getAttributStromausfall()
  {
    return m_attributStromausfall;
  }

  /**
   * Holt den Wert des Attribut, das den Stomausfall anzeigt.
   * 
   * @return Wert des Attribut, das den Stomausfall anzeigt.
   */
  public String getAttributWertStromausfall()
  {
    return m_attributWertStromausfall;
  }

  /**
   * Holt die Information, ob die enthaltenen Daten zur Stromausfall-Erkennung einsetzbar bzw. versorgt sind.
   * 
   * @return <code>true</code>, wenn die enthaltenen Daten zur Stromausfall-Erkennung einsetzbar bzw. versorgt sind, sonst <code>false</code>.
   */
  public boolean isVersorgtStromausfall()
  {
    return m_versorgtStromausfall;
  }

  /**
   * Holt die Liste der versorgten DE's fr die Erkennung des Trkontakts.
   * 
   * @return Liste der versorgten DE's fr die Erkennung des Trkontakts.
   */
  public List<SystemObject> getDesTuerkontakt()
  {
    return m_desTuerkontakt;
  }

  /**
   * Holt die AttributGruppe, die die Daten zum Trkontakt liefert.
   * 
   * @return AttributGruppe, die die Daten zum Trkontakt liefert.
   */
  public AttributeGroup getAtgTuerkontakt()
  {
    return m_atgTuerkontakt;
  }

  /**
   * Holt den Aspekt, unter dem die Daten zum Trkontakt geliefert werden.
   * 
   * @return Aspekt, unter dem die Daten zum Trkontakt geliefert werden.
   */
  public Aspect getAspTuerkontakt()
  {
    return m_aspTuerkontakt;
  }

  /**
   * Holt das Attribut, das die Trkontakt-Information enthlt.
   * 
   * @return Attribut, das die Trkontakt-Information enthlt.
   */
  public String getAttributTuerkontakt()
  {
    return m_attributTuerkontakt;
  }

  /**
   * Holt den Wert des Attribut, das den Trkontakt anzeigt.
   * 
   * @return Wert des Attribut, das den Trkontakt anzeigt.
   */
  public String getAttributWertTuerkontakt()
  {
    return m_attributWertTuerkontakt;
  }

  /**
   * Holt die Information, ob die enthaltenen Daten zur Trkontakt-Erkennung einsetzbar bzw. versorgt sind.
   * 
   * @return <code>true</code>, wenn die enthaltenen Daten zur Trkontakt-Erkennung einsetzbar bzw. versorgt sind, sonst <code>false</code>.
   */
  public boolean isVersorgtTuerkontakt()
  {
    return m_versorgtTuerkontakt;
  }
}
