/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.agzs.tls;

/**
 * Klasse fr die Speicherung der Informationen eines Konfigurationsobjektes vom Typ typ.wvzInhaltUmsetzungTls.
 *
 * @version $Revision: 1.1 $ / $Date: 2008/09/15 08:37:49 $ / ($Author: Drapp $)
 *
 * @author Dambach-Werke GmbH
 * @author Thomas Drapp
 *
 */
public class WvzInhaltUmsetzungTls
{
  /**
   * Code auf TLS-Seite fr den WVZ-Inhalt
   */
  int m_code;
  /**
   * Pid des WVZ-Inhalts auf AnzeigenGlobal-Seite (Objekt vom Typ typ.wvzInhalt)
   */
  String m_pidWvzInhalt;
  /**
   * WVZ-Inhalts auf AnzeigenGlobal-Seite (z.B.: "TLS.Gefahrenstelle", "TLS.Baustelle", "DWISTA.Stadion", "TLS.Stau", "Dunkel", "DWISTA.Stau"}
   */
  String m_wvzInhalt;
 
  /**
   * Konstruktor mit der bergabe der Pid des WVZ-Inhalt, dem WVZ-Inhalt und dem WVZ-Code.
   * 
   * @param pidWvzInhalt Pid des WVZ-Inhalt.
   * @param wvzInhalt eindeutige Bezeichnung des WVZ-Inhalt.
   * @param code TLS-Code des WVZ-Inhalt.
   */
  public WvzInhaltUmsetzungTls(String pidWvzInhalt, String wvzInhalt, int code)
  {
    m_pidWvzInhalt = pidWvzInhalt;
    m_wvzInhalt = wvzInhalt;
    m_code = code;
  }
  
  /**
   * Holen die Pid des WVZ-Inhalt.
   * 
   * @return Pid des WVZ-Inhalt.
   */
  public String getPidWvzInhalt()
  {
    return m_pidWvzInhalt;
  }
  
  /**
   * Setzen die Pid des WVZ-Inhalt.
   * 
   * @param pidWvzInhalt Pid des WVZ-Inhalt.
   */
  public void setPidWvzInhalt(String pidWvzInhalt)
  {
    m_pidWvzInhalt = pidWvzInhalt;
  }
  
  /**
   * Holen des TLS-Code des WVZ-Inhalt.
   * 
   * @return TLS-Code des WVZ-Inhalt.
   */
  public int getCode()
  {
    return m_code;
  }
  
  /**
   * Setzen des TLS-Code des WVZ-Inhalt.
   * 
   * @param code TLS-Code des WVZ-Inhalt.
   */
  public void setCode(int code)
  {
    m_code = code;
  }

  /**
   * Holen der eindeutige Bezeichnung des WVZ-Inhalt.
   * 
   * @return eindeutige Bezeichnung des WVZ-Inhalt.
   */
  public String getWvzInhalt()
  {
    return m_wvzInhalt;
  }

  /**
   * Setzen der eindeutige Bezeichnung des WVZ-Inhalt.
   * 
   * @param wvzInhalt eindeutige Bezeichnung des WVZ-Inhalt.
   */
  public void setWvzInhalt(String wvzInhalt)
  {
    m_wvzInhalt = wvzInhalt;
  }
}
